==> gnustep-base_1.10.3.orig.tar.gz: gnustep-base-1.10.3.orig/Headers/Additions/GNUstepBase/unicode/cyrillic.h <==
// ISO_8859-5,1988 to Unicode maping

const unsigned int Cyrillic_conv_base = 0x80;

unichar Cyrillic_char_to_uni_table[] =
{
  0x0080,
  0x0081,
  0x0082,
  0x0083,
  0x0084,
  0x0085,
  0x0086,
  0x0087,
  0x0088,
  0x0089,
  0x008A,
  0x008B,
  0x008C,
  0x008D,
  0x008E,
  0x008F,
  0x0090,
  0x0091,
  0x0092,
  0x0093,
  0x0094,
  0x0095,
  0x0096,
  0x0097,
  0x0098,
  0x0099,
  0x009A,
  0x009B,
  0x009C,
  0x009D,
  0x009E,
  0x009F,
  0x00A0,
  0x0401,
  0x0402,
  0x0403,
  0x0404,
  0x0405,
  0x0406,
  0x0407,
  0x0408,
  0x0409,
  0x040A,
  0x040B,
  0x040C,
  0x00AD,
  0x040E,
  0x040F,
  0x0410,
  0x0411,
  0x0412,
  0x0413,
  0x0414,
  0x0415,
  0x0416,
  0x0417,
  0x0418,
  0x0419,
  0x041A,
  0x041B,
  0x041C,
  0x041D,
  0x041E,
  0x041F,
  0x0420,
  0x0421,
  0x0422,
  0x0423,
  0x0424,
  0x0425,
  0x0426,
  0x0427,
  0x0428,
  0x0429,
  0x042A,
  0x042B,
  0x042C,
  0x042D,
  0x042E,
  0x042F,
  0x0430,
  0x0431,
  0x0432,
  0x0433,
  0x0434,
  0x0435,
  0x0436,
  0x0437,
  0x0438,
  0x0439,
  0x043A,
  0x043B,
  0x043C,
  0x043D,
  0x043E,
  0x043F,
  0x0440,
  0x0441,
  0x0442,
  0x0443,
  0x0444,
  0x0445,
  0x0446,
  0x0447,
  0x0448,
  0x0449,
  0x044A,
  0x044B,
  0x044C,
  0x044D,
  0x044E,
  0x044F,
  0x2116,
  0x0451,
  0x0452,
  0x0453,
  0x0454,
  0x0455,
  0x0456,
  0x0457,
  0x0458,
  0x0459,
  0x045A,
  0x045B,
  0x045C,
  0x00A7,
  0x045E,
  0x045F,
};

// Unicode to ISO_8859-5,1988 maping

const unsigned int Cyrillic_uni_to_char_table_size = 128;

_ucc_ Cyrillic_uni_to_char_table[]=
{
  {0x0080,0x80},
  {0x0081,0x81},
  {0x0082,0x82},
  {0x0083,0x83},
  {0x0084,0x84},
  {0x0085,0x85},
  {0x0086,0x86},
  {0x0087,0x87},
  {0x0088,0x88},
  {0x0089,0x89},
  {0x008A,0x8A},
  {0x008B,0x8B},
  {0x008C,0x8C},
  {0x008D,0x8D},
  {0x008E,0x8E},
  {0x008F,0x8F},
  {0x0090,0x90},
  {0x0091,0x91},
  {0x0092,0x92},
  {0x0093,0x93},
  {0x0094,0x94},
  {0x0095,0x95},
  {0x0096,0x96},
  {0x0097,0x97},
  {0x0098,0x98},
  {0x0099,0x99},
  {0x009A,0x9A},
  {0x009B,0x9B},
  {0x009C,0x9C},
  {0x009D,0x9D},
  {0x009E,0x9E},
  {0x009F,0x9F},
  {0x00A0,0xA0},
  {0x00A7,0xFD},
  {0x00AD,0xAD},
  {0x0401,0xA1},
  {0x0402,0xA2},
  {0x0403,0xA3},
  {0x0404,0xA4},
  {0x0405,0xA5},
  {0x0406,0xA6},
  {0x0407,0xA7},
  {0x0408,0xA8},
  {0x0409,0xA9},
  {0x040A,0xAA},
  {0x040B,0xAB},
  {0x040C,0xAC},
  {0x040E,0xAE},
  {0x040F,0xAF},
  {0x0410,0xB0},
  {0x0411,0xB1},
  {0x0412,0xB2},
  {0x0413,0xB3},
  {0x0414,0xB4},
  {0x0415,0xB5},
  {0x0416,0xB6},
  {0x0417,0xB7},
  {0x0418,0xB8},
  {0x0419,0xB9},
  {0x041A,0xBA},
  {0x041B,0xBB},
  {0x041C,0xBC},
  {0x041D,0xBD},
  {0x041E,0xBE},
  {0x041F,0xBF},
  {0x0420,0xC0},
  {0x0421,0xC1},
  {0x0422,0xC2},
  {0x0423,0xC3},
  {0x0424,0xC4},
  {0x0425,0xC5},
  {0x0426,0xC6},
  {0x0427,0xC7},
  {0x0428,0xC8},
  {0x0429,0xC9},
  {0x042A,0xCA},
  {0x042B,0xCB},
  {0x042C,0xCC},
  {0x042D,0xCD},
  {0x042E,0xCE},
  {0x042F,0xCF},
  {0x0430,0xD0},
  {0x0431,0xD1},
  {0x0432,0xD2},
  {0x0433,0xD3},
  {0x0434,0xD4},
  {0x0435,0xD5},
  {0x0436,0xD6},
  {0x0437,0xD7},
  {0x0438,0xD8},
  {0x0439,0xD9},
  {0x043A,0xDA},
  {0x043B,0xDB},
  {0x043C,0xDC},
  {0x043D,0xDD},
  {0x043E,0xDE},
  {0x043F,0xDF},
  {0x0440,0xE0},
  {0x0441,0xE1},
  {0x0442,0xE2},
  {0x0443,0xE3},
  {0x0444,0xE4},
  {0x0445,0xE5},
  {0x0446,0xE6},
  {0x0447,0xE7},
  {0x0448,0xE8},
  {0x0449,0xE9},
  {0x044A,0xEA},
  {0x044B,0xEB},
  {0x044C,0xEC},
  {0x044D,0xED},
  {0x044E,0xEE},
  {0x044F,0xEF},
  {0x0451,0xF1},
  {0x0452,0xF2},
  {0x0453,0xF3},
  {0x0454,0xF4},
  {0x0455,0xF5},
  {0x0456,0xF6},
  {0x0457,0xF7},
  {0x0458,0xF8},
  {0x0459,0xF9},
  {0x045A,0xFA},
  {0x045B,0xFB},
  {0x045C,0xFC},
  {0x045E,0xFE},
  {0x045F,0xFF},
  {0x2116,0xF0},
};

==> gnustep-base_1.13.0.orig.tar.gz: gnustep-base-1.13.0/Headers/Additions/GNUstepBase/unicode/cyrillic.h <==
// ISO_8859-5,1988 to Unicode maping
/*
  Copyright (C) 2005 Free Software Foundation

  Copying and distribution of this file, with or without modification,
  are permitted in any medium without royalty provided the copyright
  notice and this notice are preserved.
*/


const unsigned int Cyrillic_conv_base = 0x80;

unichar Cyrillic_char_to_uni_table[] =
{
  0x0080,
  0x0081,
  0x0082,
  0x0083,
  0x0084,
  0x0085,
  0x0086,
  0x0087,
  0x0088,
  0x0089,
  0x008A,
  0x008B,
  0x008C,
  0x008D,
  0x008E,
  0x008F,
  0x0090,
  0x0091,
  0x0092,
  0x0093,
  0x0094,
  0x0095,
  0x0096,
  0x0097,
  0x0098,
  0x0099,
  0x009A,
  0x009B,
  0x009C,
  0x009D,
  0x009E,
  0x009F,
  0x00A0,
  0x0401,
  0x0402,
  0x0403,
  0x0404,
  0x0405,
  0x0406,
  0x0407,
  0x0408,
  0x0409,
  0x040A,
  0x040B,
  0x040C,
  0x00AD,
  0x040E,
  0x040F,
  0x0410,
  0x0411,
  0x0412,
  0x0413,
  0x0414,
  0x0415,
  0x0416,
  0x0417,
  0x0418,
  0x0419,
  0x041A,
  0x041B,
  0x041C,
  0x041D,
  0x041E,
  0x041F,
  0x0420,
  0x0421,
  0x0422,
  0x0423,
  0x0424,
  0x0425,
  0x0426,
  0x0427,
  0x0428,
  0x0429,
  0x042A,
  0x042B,
  0x042C,
  0x042D,
  0x042E,
  0x042F,
  0x0430,
  0x0431,
  0x0432,
  0x0433,
  0x0434,
  0x0435,
  0x0436,
  0x0437,
  0x0438,
  0x0439,
  0x043A,
  0x043B,
  0x043C,
  0x043D,
  0x043E,
  0x043F,
  0x0440,
  0x0441,
  0x0442,
  0x0443,
  0x0444,
  0x0445,
  0x0446,
  0x0447,
  0x0448,
  0x0449,
  0x044A,
  0x044B,
  0x044C,
  0x044D,
  0x044E,
  0x044F,
  0x2116,
  0x0451,
  0x0452,
  0x0453,
  0x0454,
  0x0455,
  0x0456,
  0x0457,
  0x0458,
  0x0459,
  0x045A,
  0x045B,
  0x045C,
  0x00A7,
  0x045E,
  0x045F,
};

// Unicode to ISO_8859-5,1988 maping

const unsigned int Cyrillic_uni_to_char_table_size = 128;

_ucc_ Cyrillic_uni_to_char_table[]=
{
  {0x0080,0x80},
  {0x0081,0x81},
  {0x0082,0x82},
  {0x0083,0x83},
  {0x0084,0x84},
  {0x0085,0x85},
  {0x0086,0x86},
  {0x0087,0x87},
  {0x0088,0x88},
  {0x0089,0x89},
  {0x008A,0x8A},
  {0x008B,0x8B},
  {0x008C,0x8C},
  {0x008D,0x8D},
  {0x008E,0x8E},
  {0x008F,0x8F},
  {0x0090,0x90},
  {0x0091,0x91},
  {0x0092,0x92},
  {0x0093,0x93},
  {0x0094,0x94},
  {0x0095,0x95},
  {0x0096,0x96},
  {0x0097,0x97},
  {0x0098,0x98},
  {0x0099,0x99},
  {0x009A,0x9A},
  {0x009B,0x9B},
  {0x009C,0x9C},
  {0x009D,0x9D},
  {0x009E,0x9E},
  {0x009F,0x9F},
  {0x00A0,0xA0},
  {0x00A7,0xFD},
  {0x00AD,0xAD},
  {0x0401,0xA1},
  {0x0402,0xA2},
  {0x0403,0xA3},
  {0x0404,0xA4},
  {0x0405,0xA5},
  {0x0406,0xA6},
  {0x0407,0xA7},
  {0x0408,0xA8},
  {0x0409,0xA9},
  {0x040A,0xAA},
  {0x040B,0xAB},
  {0x040C,0xAC},
  {0x040E,0xAE},
  {0x040F,0xAF},
  {0x0410,0xB0},
  {0x0411,0xB1},
  {0x0412,0xB2},
  {0x0413,0xB3},
  {0x0414,0xB4},
  {0x0415,0xB5},
  {0x0416,0xB6},
  {0x0417,0xB7},
  {0x0418,0xB8},
  {0x0419,0xB9},
  {0x041A,0xBA},
  {0x041B,0xBB},
  {0x041C,0xBC},
  {0x041D,0xBD},
  {0x041E,0xBE},
  {0x041F,0xBF},
  {0x0420,0xC0},
  {0x0421,0xC1},
  {0x0422,0xC2},
  {0x0423,0xC3},
  {0x0424,0xC4},
  {0x0425,0xC5},
  {0x0426,0xC6},
  {0x0427,0xC7},
  {0x0428,0xC8},
  {0x0429,0xC9},
  {0x042A,0xCA},
  {0x042B,0xCB},
  {0x042C,0xCC},
  {0x042D,0xCD},
  {0x042E,0xCE},
  {0x042F,0xCF},
  {0x0430,0xD0},
  {0x0431,0xD1},
  {0x0432,0xD2},
  {0x0433,0xD3},
  {0x0434,0xD4},
  {0x0435,0xD5},
  {0x0436,0xD6},
  {0x0437,0xD7},
  {0x0438,0xD8},
  {0x0439,0xD9},
  {0x043A,0xDA},
  {0x043B,0xDB},
  {0x043C,0xDC},
  {0x043D,0xDD},
  {0x043E,0xDE},
  {0x043F,0xDF},
  {0x0440,0xE0},
  {0x0441,0xE1},
  {0x0442,0xE2},
  {0x0443,0xE3},
  {0x0444,0xE4},
  {0x0445,0xE5},
  {0x0446,0xE6},
  {0x0447,0xE7},
  {0x0448,0xE8},
  {0x0449,0xE9},
  {0x044A,0xEA},
  {0x044B,0xEB},
  {0x044C,0xEC},
  {0x044D,0xED},
  {0x044E,0xEE},
  {0x044F,0xEF},
  {0x0451,0xF1},
  {0x0452,0xF2},
  {0x0453,0xF3},
  {0x0454,0xF4},
  {0x0455,0xF5},
  {0x0456,0xF6},
  {0x0457,0xF7},
  {0x0458,0xF8},
  {0x0459,0xF9},
  {0x045A,0xFA},
  {0x045B,0xFB},
  {0x045C,0xFC},
  {0x045E,0xFE},
  {0x045F,0xFF},
  {0x2116,0xF0},
};
